@@ -43,7 +43,7 @@
 #' @return A list of graph attributes, or a single graph attribute.
 #'
 #' @aliases get.graph.attribute graph.attributes
-#' @family graph attributes
+#' @family attributes
 #'
 #' @export
 #' @examples
@@ -57,7 +57,7 @@ graph_attr <- function(graph, name) {
   if (missing(name)) {
     graph.attributes(graph)
   } else {
-    .Call(C_R_igraph_mybracket2, graph, igraph_t_idx_attr, igraph_attr_idx_graph)[[as.character(name)]]
+    .Call(R_igraph_mybracket2, graph, igraph_t_idx_attr, igraph_attr_idx_graph)[[as.character(name)]]
   }
 }
 
@@ -72,7 +72,7 @@ graph_attr <- function(graph, name) {
 #' @return The graph, with the attribute(s) added.
 #'
 #' @aliases graph.attributes<-
-#' @family graph attributes
+#' @family attributes
 #'
 #' @export
 #' @examples
@@ -102,7 +102,7 @@ graph_attr <- function(graph, name) {
 #' @param value New value of the attribute.
 #' @return The graph with the new graph attribute added or set.
 #'
-#' @family graph attributes
+#' @family attributes
 #' @aliases set.graph.attribute
 #'
 #' @export
@@ -116,7 +116,7 @@ set_graph_attr <- function(graph, name, value) {
     stop("Not a graph object")
   }
 
-  .Call(C_R_igraph_mybracket3_set, graph, igraph_t_idx_attr, igraph_attr_idx_graph, name, value)
+  .Call(R_igraph_mybracket3_set, graph, igraph_t_idx_attr, igraph_attr_idx_graph, name, value)
 }
 
 #' @export
@@ -124,7 +124,7 @@ graph.attributes <- function(graph) {
   if (!is_igraph(graph)) {
     stop("Not a graph object")
   }
-  .Call(C_R_igraph_mybracket2_copy, graph, igraph_t_idx_attr, igraph_attr_idx_graph)
+  .Call(R_igraph_mybracket2_copy, graph, igraph_t_idx_attr, igraph_attr_idx_graph)
 }
 
 #' @export
@@ -137,7 +137,7 @@ graph.attributes <- function(graph) {
     stop("Value must be a named list with unique names")
   }
 
-  .Call(C_R_igraph_mybracket2_set, graph, igraph_t_idx_attr, igraph_attr_idx_graph, value)
+  .Call(R_igraph_mybracket2_set, graph, igraph_t_idx_attr, igraph_attr_idx_graph, value)
 }
 
 
@@ -152,7 +152,7 @@ graph.attributes <- function(graph) {
 #'   all vertex attributes, if `name` is missing.
 #'
 #' @aliases get.vertex.attribute vertex.attributes
-#' @family graph attributes
+#' @family attributes
 #'
 #' @export
 #' @examples
@@ -174,7 +174,7 @@ vertex_attr <- function(graph, name, index = V(graph)) {
     }
   } else {
     myattr <-
-      .Call(C_R_igraph_mybracket2, graph, igraph_t_idx_attr, igraph_attr_idx_vertex)[[as.character(name)]]
+      .Call(R_igraph_mybracket2, graph, igraph_t_idx_attr, igraph_attr_idx_vertex)[[as.character(name)]]
     if (is_complete_iterator(index)) {
       myattr
     } else {
@@ -197,7 +197,7 @@ vertex_attr <- function(graph, name, index = V(graph)) {
 #' @return The graph, with the vertex attribute(s) added or set.
 #'
 #' @aliases vertex.attributes<-
-#' @family graph attributes
+#' @family attributes
 #'
 #' @export
 #' @examples
@@ -229,7 +229,7 @@ vertex_attr <- function(graph, name, index = V(graph)) {
 #' @return The graph, with the vertex attribute added or set.
 #'
 #' @aliases set.vertex.attribute
-#' @family graph attributes
+#' @family attributes
 #'
 #' @export
 #' @examples
@@ -261,7 +261,7 @@ i_set_vertex_attr <- function(graph, name, index = V(graph), value, check = TRUE
   }
   name <- as.character(name)
 
-  vattrs <- .Call(C_R_igraph_mybracket2, graph, igraph_t_idx_attr, igraph_attr_idx_vertex)
+  vattrs <- .Call(R_igraph_mybracket2, graph, igraph_t_idx_attr, igraph_attr_idx_vertex)
 
   if (!complete && !(name %in% names(vattrs))) {
     vattrs[[name]] <- value[rep.int(NA_integer_, vcount(graph))]
@@ -291,7 +291,7 @@ i_set_vertex_attr <- function(graph, name, index = V(graph), value, check = TRUE
     }
   }
 
-  .Call(C_R_igraph_mybracket2_set, graph, igraph_t_idx_attr, igraph_attr_idx_vertex, vattrs)
+  .Call(R_igraph_mybracket2_set, graph, igraph_t_idx_attr, igraph_attr_idx_vertex, vattrs)
 }
 
 #' @export
@@ -304,7 +304,7 @@ vertex.attributes <- function(graph, index = V(graph)) {
     index <- as.igraph.vs(graph, index)
   }
 
-  res <- .Call(C_R_igraph_mybracket2_copy, graph, igraph_t_idx_attr, igraph_attr_idx_vertex)
+  res <- .Call(R_igraph_mybracket2_copy, graph, igraph_t_idx_attr, igraph_attr_idx_vertex)
 
   if (!missing(index) &&
     (length(index) != vcount(graph) || any(index != V(graph)))) {
@@ -348,7 +348,7 @@ vertex.attributes <- function(graph, index = V(graph)) {
     }
   }
 
-  .Call(C_R_igraph_mybracket2_set, graph, igraph_t_idx_attr, igraph_attr_idx_vertex, value)
+  .Call(R_igraph_mybracket2_set, graph, igraph_t_idx_attr, igraph_attr_idx_vertex, value)
 }
 
 
@@ -363,7 +363,7 @@ vertex.attributes <- function(graph, index = V(graph)) {
 #'   edge attributes if `name` is missing.
 #'
 #' @aliases get.edge.attribute edge.attributes
-#' @family graph attributes
+#' @family attributes
 #'
 #' @export
 #' @examples
@@ -384,7 +384,7 @@ edge_attr <- function(graph, name, index = E(graph)) {
     }
   } else {
     name <- as.character(name)
-    myattr <- .Call(C_R_igraph_mybracket2, graph, igraph_t_idx_attr, igraph_attr_idx_edge)[[name]]
+    myattr <- .Call(R_igraph_mybracket2, graph, igraph_t_idx_attr, igraph_attr_idx_edge)[[name]]
     if (is_complete_iterator(index)) {
       myattr
     } else {
@@ -407,7 +407,7 @@ edge_attr <- function(graph, name, index = E(graph)) {
 #' @return The graph, with the edge attribute(s) added or set.
 #'
 #' @aliases edge.attributes<-
-#' @family graph attributes
+#' @family attributes
 #'
 #' @export
 #' @examples
@@ -439,7 +439,7 @@ edge_attr <- function(graph, name, index = E(graph)) {
 #' @return The graph, with the edge attribute added or set.
 #'
 #' @aliases set.edge.attribute
-#' @family graph attributes
+#' @family attributes
 #'
 #' @export
 #' @examples
@@ -471,7 +471,7 @@ i_set_edge_attr <- function(graph, name, index = E(graph), value, check = TRUE)
     index <- as.igraph.es(graph, index)
   }
 
-  eattrs <- .Call(C_R_igraph_mybracket2, graph, igraph_t_idx_attr, igraph_attr_idx_edge)
+  eattrs <- .Call(R_igraph_mybracket2, graph, igraph_t_idx_attr, igraph_attr_idx_edge)
 
   if (!complete && !(name %in% names(eattrs))) {
     eattrs[[name]] <- value[rep.int(NA_integer_, ecount(graph))]
@@ -501,7 +501,7 @@ i_set_edge_attr <- function(graph, name, index = E(graph), value, check = TRUE)
     }
   }
 
-  .Call(C_R_igraph_mybracket2_set, graph, igraph_t_idx_attr, igraph_attr_idx_edge, eattrs)
+  .Call(R_igraph_mybracket2_set, graph, igraph_t_idx_attr, igraph_attr_idx_edge, eattrs)
 }
 
 #' @export
@@ -514,7 +514,7 @@ edge.attributes <- function(graph, index = E(graph)) {
     index <- as.igraph.es(graph, index)
   }
 
-  res <- .Call(C_R_igraph_mybracket2_copy, graph, igraph_t_idx_attr, igraph_attr_idx_edge)
+  res <- .Call(R_igraph_mybracket2_copy, graph, igraph_t_idx_attr, igraph_attr_idx_edge)
 
   if (!missing(index) &&
     (length(index) != ecount(graph) || any(index != E(graph)))) {
@@ -558,7 +558,7 @@ edge.attributes <- function(graph, index = E(graph)) {
     }
   }
 
-  .Call(C_R_igraph_mybracket2_set, graph, igraph_t_idx_attr, igraph_attr_idx_edge, value)
+  .Call(R_igraph_mybracket2_set, graph, igraph_t_idx_attr, igraph_attr_idx_edge, value)
 }
 
 #' List names of graph attributes
@@ -567,7 +567,7 @@ edge.attributes <- function(graph, index = E(graph)) {
 #' @return Character vector, the names of the graph attributes.
 #'
 #' @aliases list.graph.attributes attributes
-#' @family graph attributes
+#' @family attributes
 #'
 #' @export
 #' @examples
@@ -577,7 +577,7 @@ graph_attr_names <- function(graph) {
   if (!is_igraph(graph)) {
     stop("Not a graph object")
   }
-  res <- .Call(C_R_igraph_mybracket2_names, graph, igraph_t_idx_attr, igraph_attr_idx_graph)
+  res <- .Call(R_igraph_mybracket2_names, graph, igraph_t_idx_attr, igraph_attr_idx_graph)
   if (is.null(res)) {
     res <- character()
   }
@@ -590,7 +590,7 @@ graph_attr_names <- function(graph) {
 #' @return Character vector, the names of the vertex attributes.
 #'
 #' @aliases list.vertex.attributes
-#' @family graph attributes
+#' @family attributes
 #'
 #' @export
 #' @examples
@@ -603,7 +603,7 @@ vertex_attr_names <- function(graph) {
   if (!is_igraph(graph)) {
     stop("Not a graph object")
   }
-  res <- .Call(C_R_igraph_mybracket2_names, graph, igraph_t_idx_attr, igraph_attr_idx_vertex)
+  res <- .Call(R_igraph_mybracket2_names, graph, igraph_t_idx_attr, igraph_attr_idx_vertex)
 
   if (is.null(res)) {
     res <- character()
@@ -617,7 +617,7 @@ vertex_attr_names <- function(graph) {
 #' @return Character vector, the names of the edge attributes.
 #'
 #' @aliases list.edge.attributes
-#' @family graph attributes
+#' @family attributes
 #'
 #' @export
 #' @examples
@@ -629,7 +629,7 @@ edge_attr_names <- function(graph) {
   if (!is_igraph(graph)) {
     stop("Not a graph object")
   }
-  res <- .Call(C_R_igraph_mybracket2_names, graph, igraph_t_idx_attr, igraph_attr_idx_edge)
+  res <- .Call(R_igraph_mybracket2_names, graph, igraph_t_idx_attr, igraph_attr_idx_edge)
   if (is.null(res)) {
     res <- character()
   }
@@ -643,7 +643,7 @@ edge_attr_names <- function(graph) {
 #' @return The graph, with the specified attribute removed.
 #'
 #' @aliases remove.graph.attribute
-#' @family graph attributes
+#' @family attributes
 #'
 #' @export
 #' @examples
@@ -660,10 +660,10 @@ delete_graph_attr <- function(graph, name) {
     stop("No such graph attribute: ", name)
   }
 
-  gattr <- .Call(C_R_igraph_mybracket2, graph, igraph_t_idx_attr, igraph_attr_idx_graph)
+  gattr <- .Call(R_igraph_mybracket2, graph, igraph_t_idx_attr, igraph_attr_idx_graph)
   gattr[[name]] <- NULL
 
-  .Call(C_R_igraph_mybracket2_set, graph, igraph_t_idx_attr, igraph_attr_idx_graph, gattr)
+  .Call(R_igraph_mybracket2_set, graph, igraph_t_idx_attr, igraph_attr_idx_graph, gattr)
 }
 
 #' Delete a vertex attribute
@@ -673,7 +673,7 @@ delete_graph_attr <- function(graph, name) {
 #' @return The graph, with the specified vertex attribute removed.
 #'
 #' @aliases remove.vertex.attribute
-#' @family graph attributes
+#' @family attributes
 #'
 #' @export
 #' @examples
@@ -691,10 +691,10 @@ delete_vertex_attr <- function(graph, name) {
     stop("No such vertex attribute: ", name)
   }
 
-  vattr <- .Call(C_R_igraph_mybracket2, graph, igraph_t_idx_attr, igraph_attr_idx_vertex)
+  vattr <- .Call(R_igraph_mybracket2, graph, igraph_t_idx_attr, igraph_attr_idx_vertex)
   vattr[[name]] <- NULL
 
-  .Call(C_R_igraph_mybracket2_set, graph, igraph_t_idx_attr, igraph_attr_idx_vertex, vattr)
+  .Call(R_igraph_mybracket2_set, graph, igraph_t_idx_attr, igraph_attr_idx_vertex, vattr)
 }
 
 #' Delete an edge attribute
@@ -704,7 +704,7 @@ delete_vertex_attr <- function(graph, name) {
 #' @return The graph, with the specified edge attribute removed.
 #'
 #' @aliases remove.edge.attribute
-#' @family graph attributes
+#' @family attributes
 #'
 #' @export
 #' @examples
@@ -722,10 +722,10 @@ delete_edge_attr <- function(graph, name) {
     stop("No such edge attribute: ", name)
   }
 
-  eattr <- .Call(C_R_igraph_mybracket2, graph, igraph_t_idx_attr, igraph_attr_idx_edge)
+  eattr <- .Call(R_igraph_mybracket2, graph, igraph_t_idx_attr, igraph_attr_idx_edge)
   eattr[[name]] <- NULL
 
-  .Call(C_R_igraph_mybracket2_set, graph, igraph_t_idx_attr, igraph_attr_idx_edge, eattr)
+  .Call(R_igraph_mybracket2_set, graph, igraph_t_idx_attr, igraph_attr_idx_edge, eattr)
 }
 
 #############
@@ -809,6 +809,7 @@ is_weighted <- function(graph) {
 }
 
 #' @rdname make_bipartite_graph
+#' @family bipartite
 #' @export
 is_bipartite <- function(graph) {
   if (!is_igraph(graph)) {
@@ -895,6 +896,7 @@ igraph.i.attribute.combination <- function(comb) {
 #' new edge should be sum of the weights of the corresponding edges in the old
 #' graph; and that the rest of the attributes should be ignored (=dropped).
 #'
+#' @family attributes
 #' @name igraph-attribute-combination
 #' @aliases attribute.combination
 #' @section Predefined combination functions: The following combination
@@ -929,7 +931,7 @@ igraph.i.attribute.combination <- function(comb) {
 #' @keywords graphs
 #' @examples
 #'
-#' g <- graph(c(1, 2, 1, 2, 1, 2, 2, 3, 3, 4))
+#' g <- make_graph(c(1, 2, 1, 2, 1, 2, 2, 3, 3, 4))
 #' E(g)$weight <- 1:5
 #'
 #' ## print attribute values with the graph
@@ -971,7 +973,7 @@ NULL
 #' @method $ igraph
 #' @name igraph-dollar
 #' @export
-#' @family graph attributes
+#' @family attributes
 #' @examples
 #' g <- make_ring(10)
 #' g$name
