@@ -115,10 +115,10 @@ bipartite_projection <- function(graph, types = NULL,
     warning("`probe1' ignored if only one projection is requested")
   }
 
-  on.exit(.Call(C_R_igraph_finalizer))
+  on.exit(.Call(R_igraph_finalizer))
   # Function call
   res <- .Call(
-    C_R_igraph_bipartite_projection, graph, types,
+    R_igraph_bipartite_projection, graph, types,
     as.integer(probe1), which
   )
   if (remove.type) {
@@ -148,6 +148,8 @@ bipartite_projection <- function(graph, types = NULL,
   }
 }
 
+#' @export
+bipartite_projection_size <- bipartite_projection_size_impl
 
 #' Decide whether a graph is bipartite
 #'
@@ -193,4 +195,4 @@ bipartite_projection <- function(graph, types = NULL,
 #' bipartite_mapping(g3)
 #' @family bipartite
 #' @export
-bipartite_mapping <- bipartite_mapping
+bipartite_mapping <- is_bipartite_impl
