@@ -25,13 +25,13 @@
 ###################################################################
 
 update_es_ref <- update_vs_ref <- function(graph) {
-  env <- get_vs_ref(graph)
+  env <- get_es_ref(graph)
   if (!is.null(env)) assign("me", graph, envir = env)
 }
 
 get_es_ref <- get_vs_ref <- function(graph) {
   if (is_igraph(graph) && !warn_version(graph)) {
-    .Call(C_R_igraph_mybracket, graph, 10L)
+    .Call(R_igraph_mybracket, graph, igraph_t_idx_env)
   } else {
     NULL
   }
@@ -85,7 +85,7 @@ get_es_graph_id <- get_vs_graph_id <- function(seq) {
 #' @export
 identical_graphs <- function(g1, g2, attrs = TRUE) {
   stopifnot(is_igraph(g1), is_igraph(g2))
-  .Call(C_R_igraph_identical_graphs, g1, g2, as.logical(attrs))
+  .Call(R_igraph_identical_graphs, g1, g2, as.logical(attrs))
 }
 
 add_vses_graph_ref <- function(vses, graph) {
@@ -319,15 +319,15 @@ E <- function(graph, P = NULL, path = NULL, directed = TRUE) {
     res <- seq_len(ec)
     res <- set_complete_iterator(res)
   } else if (!is.null(P)) {
-    on.exit(.Call(C_R_igraph_finalizer))
+    on.exit(.Call(R_igraph_finalizer))
     res <- .Call(
-      C_R_igraph_es_pairs, graph, as.igraph.vs(graph, P) - 1,
+      R_igraph_es_pairs, graph, as.igraph.vs(graph, P) - 1,
       as.logical(directed)
     ) + 1
   } else {
-    on.exit(.Call(C_R_igraph_finalizer))
+    on.exit(.Call(R_igraph_finalizer))
     res <- .Call(
-      C_R_igraph_es_path, graph, as.igraph.vs(graph, path) - 1,
+      R_igraph_es_path, graph, as.igraph.vs(graph, path) - 1,
       as.logical(directed)
     ) + 1
   }
@@ -458,21 +458,21 @@ simple_vs_index <- function(x, i, na_ok = FALSE) {
 #'
 #' # -----------------------------------------------------------------
 #' # nei() special function
-#' g <- graph(c(1, 2, 2, 3, 2, 4, 4, 2))
+#' g <- make_graph(c(1, 2, 2, 3, 2, 4, 4, 2))
 #' V(g)[.nei(c(2, 4))]
 #' V(g)[.nei(c(2, 4), "in")]
 #' V(g)[.nei(c(2, 4), "out")]
 #'
 #' # -----------------------------------------------------------------
 #' # The same with vertex names
-#' g <- graph(~ A -+ B, B -+ C:D, D -+ B)
+#' g <- make_graph(~ A -+ B, B -+ C:D, D -+ B)
 #' V(g)[.nei(c("B", "D"))]
 #' V(g)[.nei(c("B", "D"), "in")]
 #' V(g)[.nei(c("B", "D"), "out")]
 #'
 #' # -----------------------------------------------------------------
 #' # Resolving attributes
-#' g <- graph(~ A -+ B, B -+ C:D, D -+ B)
+#' g <- make_graph(~ A -+ B, B -+ C:D, D -+ B)
 #' V(g)$color <- c("red", "red", "green", "green")
 #' V(g)[color == "red"]
 #'
@@ -525,9 +525,9 @@ simple_vs_index <- function(x, i, na_ok = FALSE) {
     if (is.logical(v)) {
       v <- which(v)
     }
-    on.exit(.Call(C_R_igraph_finalizer))
+    on.exit(.Call(R_igraph_finalizer))
     tmp <- .Call(
-      C_R_igraph_vs_nei, graph, x, as.igraph.vs(graph, v) - 1,
+      R_igraph_vs_nei, graph, x, as.igraph.vs(graph, v) - 1,
       as.numeric(mode)
     )
     tmp[as.numeric(x)]
@@ -556,9 +556,9 @@ simple_vs_index <- function(x, i, na_ok = FALSE) {
     if (is.logical(e)) {
       e <- which(e)
     }
-    on.exit(.Call(C_R_igraph_finalizer))
+    on.exit(.Call(R_igraph_finalizer))
     tmp <- .Call(
-      C_R_igraph_vs_adj, graph, x, as.igraph.es(graph, e) - 1,
+      R_igraph_vs_adj, graph, x, as.igraph.es(graph, e) - 1,
       as.numeric(3)
     )
     tmp[as.numeric(x)]
@@ -576,9 +576,9 @@ simple_vs_index <- function(x, i, na_ok = FALSE) {
     if (is.logical(e)) {
       e <- which(e)
     }
-    on.exit(.Call(C_R_igraph_finalizer))
+    on.exit(.Call(R_igraph_finalizer))
     tmp <- .Call(
-      C_R_igraph_vs_adj, graph, x, as.igraph.es(graph, e) - 1,
+      R_igraph_vs_adj, graph, x, as.igraph.es(graph, e) - 1,
       as.numeric(1)
     )
     tmp[as.numeric(x)]
@@ -592,9 +592,9 @@ simple_vs_index <- function(x, i, na_ok = FALSE) {
     if (is.logical(e)) {
       e <- which(e)
     }
-    on.exit(.Call(C_R_igraph_finalizer))
+    on.exit(.Call(R_igraph_finalizer))
     tmp <- .Call(
-      C_R_igraph_vs_adj, graph, x, as.igraph.es(graph, e) - 1,
+      R_igraph_vs_adj, graph, x, as.igraph.es(graph, e) - 1,
       as.numeric(2)
     )
     tmp[as.numeric(x)]
@@ -873,9 +873,9 @@ simple_es_index <- function(x, i, na_ok = FALSE) {
 
   .inc <- function(v) {
     ## TRUE iff the edge is incident to at least one vertex in v
-    on.exit(.Call(C_R_igraph_finalizer))
+    on.exit(.Call(R_igraph_finalizer))
     tmp <- .Call(
-      C_R_igraph_es_adj, graph, x, as.igraph.vs(graph, v) - 1,
+      R_igraph_es_adj, graph, x, as.igraph.vs(graph, v) - 1,
       as.numeric(3)
     )
     tmp[as.numeric(x)]
@@ -890,9 +890,9 @@ simple_es_index <- function(x, i, na_ok = FALSE) {
   }
   .from <- function(v) {
     ## TRUE iff the edge originates from at least one vertex in v
-    on.exit(.Call(C_R_igraph_finalizer))
+    on.exit(.Call(R_igraph_finalizer))
     tmp <- .Call(
-      C_R_igraph_es_adj, graph, x, as.igraph.vs(graph, v) - 1,
+      R_igraph_es_adj, graph, x, as.igraph.vs(graph, v) - 1,
       as.numeric(1)
     )
     tmp[as.numeric(x)]
@@ -903,9 +903,9 @@ simple_es_index <- function(x, i, na_ok = FALSE) {
   }
   .to <- function(v) {
     ## TRUE iff the edge points to at least one vertex in v
-    on.exit(.Call(C_R_igraph_finalizer))
+    on.exit(.Call(R_igraph_finalizer))
     tmp <- .Call(
-      C_R_igraph_es_adj, graph, x, as.igraph.vs(graph, v) - 1,
+      R_igraph_es_adj, graph, x, as.igraph.vs(graph, v) - 1,
       as.numeric(2)
     )
     tmp[as.numeric(x)]
@@ -932,8 +932,8 @@ simple_es_index <- function(x, i, na_ok = FALSE) {
         .inc = .inc, inc = inc, adj = adj,
         .from = .from, from = from,
         .to = .to, to = to,
-        .igraph.from = list(.Call(C_R_igraph_mybracket, graph, igraph_t_idx_from)[as.numeric(x)]),
-        .igraph.to = list(.Call(C_R_igraph_mybracket, graph, igraph_t_idx_to)[as.numeric(x)]),
+        .igraph.from = list(.Call(R_igraph_mybracket, graph, igraph_t_idx_from)[as.numeric(x)]),
+        .igraph.to = list(.Call(R_igraph_mybracket, graph, igraph_t_idx_to)[as.numeric(x)]),
         .igraph.graph = list(graph),
         `%--%` = `%--%`, `%->%` = `%->%`, `%<-%` = `%<-%`,
         .env = env,
@@ -1063,7 +1063,7 @@ simple_es_index <- function(x, i, na_ok = FALSE) {
 #'
 #' @export
 #' @family vertex and edge sequences
-#' @family graph attributes
+#' @family attributes
 #' @examples
 #' g <- make_(
 #'   ring(10),
@@ -1262,13 +1262,18 @@ print.igraph.vs <- function(x,
                             id = igraph_opt("print.id"),
                             ...) {
   graph <- get_vs_graph(x)
+  if (!is.null(graph)) {
+    vertices <- V(graph)
+  } else {
+    vertices <- NULL
+  }
   len <- length(x)
   gid <- graph_id(x)
 
   title <- "+ " %+% chr(len) %+% "/" %+%
-    (if (is.null(graph)) "?" else chr(vcount(graph))) %+%
+    (if (is.null(vertices)) "?" else chr(length(vertices))) %+%
     (if (len == 1) " vertex" else " vertices") %+%
-    (if (!is.null(names(x))) ", named" else "") %+%
+    (if (!is.null(names(vertices))) ", named" else "") %+%
     (if (isTRUE(id) && !is.na(gid)) paste(", from", substr(gid, 1, 7)) else "") %+%
     (if (is.null(graph)) " (deleted)" else "") %+%
     ":\n"
@@ -1288,7 +1293,14 @@ print.igraph.vs <- function(x,
   } else {
     ## Single bracket
 
-    x2 <- if (!is.null(names(x))) names(x) else as.vector(x)
+    if (!is.null(names(vertices))) {
+      x2 <- names(vertices)[as.vector(x)]
+      if (!is.null(names(x)) && !identical(names(x), x2)) {
+        names(x2) <- names(x)
+      }
+    } else {
+      x2 <- as.vector(x)
+    }
     if (length(x2)) {
       if (is.logical(full) && full) {
         print(x2, quote = FALSE)
@@ -1789,6 +1801,7 @@ rev.igraph.es <- rev.igraph.vs
 #' V(g)$name <- letters[1:10]
 #' as_ids(V(g))
 #' as_ids(E(g))
+#' @family vertex and edge sequences
 as_ids <- function(seq) {
   UseMethod("as_ids")
 }
